{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Perl.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/perl.xml and 'make bootstrap'.
module Skylighting.Syntax.Perl (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Perl.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bperl.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\196\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalarm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abinmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcaller\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchroot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bclosedir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdbmclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adbmopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bendgrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nendhostent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tendnetent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vendprotoent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bendpwent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nendservent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcntl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfileno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bformline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgetc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetgrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetgrgid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetgrnam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgethostbyaddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgethostbyname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngethostent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetlogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgetnetbyaddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgetnetbyname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgetnetent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetpeername\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetpgrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetppid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetpriority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetprotobyname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetprotobynumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetprotoent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetpwent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetpwnam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetpwuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetservbyname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetservbyport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngetservent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetsockname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngetsockopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTglob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgmtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQioctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alcfirst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlisten\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlocaltime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgrcv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgsnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aopendir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpipe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprototype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tquotemeta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areaddir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrecv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTredo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trewinddir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscalar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aseekdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsemctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsemget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsemop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsetgrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsethostent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetnetent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetpgrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetpriority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetprotoent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsetpwent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetservent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetsockopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshmctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshmget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashmread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshmwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshutdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsocket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsocketpair\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsplice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asprintf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstudy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsubstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asymlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asyscall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsyswrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atelldir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtimes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXuc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aucfirst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQumask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQutime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awaitpid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twantarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwarn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQelsif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgiven\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__END__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__DATA__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__FILE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__LINE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__PACKAGE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\toperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX!=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX~=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX+=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX-=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX*=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX/=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX**=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX|=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX||=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX//=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX&=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX&&=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX?=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH%\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX//\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX>>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH^\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX->\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX=>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH,\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX::\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apragmas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aenglish\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwarnings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsubs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTutf8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asigtrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfiletest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bconstant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbytes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdiagnostics\NUL\NUL\NUL\NUL\NUL\NUL\NULF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBackticked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBackticked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL`\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdata_handle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdata_handle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL5\\=(?:head[1-6]|over|back|item|for|begin|end|pod)\\s+.*\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpod\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__END__\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2find_here_document\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2find_here_document\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2(?|(\\w+)\\s*;?|\\s*\"([^\"]+)\"\\s*;?|\\s*`([^`]+)`\\s*;?)\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhere_document\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\s*'([^']+)'\\s*;?\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2here_document_dumb\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\s+#.*\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_brace\NUL(\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_paren\NUL[\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpattern_bracket\NUL'\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npattern_sq\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t([^\\w\\s])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apattern\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfind_qqx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfind_qqx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL(\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_2\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_3\NUL[\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_4\NUL<\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_5\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN([^a-zA-Z0-9_\\s[\\]{}()])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_6\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\s+#.*\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfind_quoted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfind_quoted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ax\\s*(')\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_6\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXqx\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfind_qqx\NULw\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afind_qw\NUL(\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_2\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_3\NUL[\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_4\NUL<\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_5\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN([^a-zA-Z0-9_\\s[\\]{}()])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_6\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\s+#.*\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afind_qw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afind_qw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL(\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEquote_word_paren\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEquote_word_brace\NUL[\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2quote_word_bracket\NUL<\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2quote_word_angular\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC([^a-zA-Z0-9_\\s[\\]{}()\\<>])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nquote_word\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\s+#.*\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfind_subst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfind_subst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\s+#.*\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsubst_curlybrace_pattern\NUL(\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_paren_pattern\NUL[\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKsubst_bracket_pattern\NUL'\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsubst_sq_pattern\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE([^\\w\\s[\\]{}()])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_slash_pattern\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_variable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\$[#_][\\w_]\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvar_detect\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULg\\$[0-9]+|[@\\$](?:[\\+\\-_]\\B|ARGV\\b|INC\\b)|[%\\$](?:INC\\b|ENV\\b|SIG\\b)|\\$\\^[A-Z_\\]\\[\\^\\?\\\\]|%([\\-\\+!]|\\^H)\SOH\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvar_detect\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\$\\$[\\$\\w_]|\\$+::\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvar_detect\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\$[^a-zA-Z0-9\\s{][A-Z]?\SOH\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvar_detect\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[\\$@%]\\{\\^?[\\w_]+\\}|[$@%]|\\*[a-zA-Z_]+\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvar_detect\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\\*[^a-zA-Z0-9\\s\\{\\(\\)\\[\\]\\}][A-Z]?\SOH\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$%*@\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4find_variable_unsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4find_variable_unsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\$[#_][\\w_]\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1var_detect_unsafe\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULC\\$[0-9]+|[@\\$](?:[\\+\\-_]\\B|ARGV\\b|INC\\b)|[%\\$](?:INC\\b|ENV\\b|SIG\\b)\SOH\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1var_detect_unsafe\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\\$\\^[A-Z_\\]\\[\\^\\?\\\\]|%([\\-\\+!]|\\^H)\SOH\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvar_detect\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\$\\$[\\$\\w_]|\\$+::\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1var_detect_unsafe\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\$[^a-zA-Z0-9\\s{][A-Z]?\SOH\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US[\\$@%]\\{\\^?[\\w_]+\\}|[$@%]|\\*\\w+\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1var_detect_unsafe\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$%*@\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhere_document\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhere_document\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT%1\\b\SOH\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\\=\\s*<<\\s*[\"']?([A-Z0-9_\\-]+)[\"']?\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhere_document\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2here_document_dumb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2here_document_dumb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tip_string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tip_string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\"\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ETX()\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ETX{}\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ETX[]\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ETX<>\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL>\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vip_string_6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\%1\b\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\DLE\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DC1\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\\\\c[^\\s\\\\]|\\\\g(\\{(\\w+|\\-\\d+)\\}|\\d+)|\\\\k(\\{\\w+\\}|<\\w+>|'\\w+')|\\\\N\\{[^\\{\\}]*\\}|\\\\o\\{[0-7]+\\}|\\\\[pP](\\{\\w+\\}|P)|\\\\x([0-9a-fA-F]{2}|\\{[0-9a-fA-F]+\\})|\\\\[0-7]{3}|\\\\[1aAbBdDeEfFGhHKlLnNQrRsStuUvVwWXzZ]\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS(?:[\\$@]\\S|%([\\w\\{\\-\\+!]|\\^H))\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4find_variable_unsafe\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#!\\/.*\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__DATA__\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdata_handle\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__END__\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\bsub\\s+\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsub_name_def\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__DATA__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__END__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__FILE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__LINE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__PACKAGE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQelsif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgiven\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX!=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH%\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX&&=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX&=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX**=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX*=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX+=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH,\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX-=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX->\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX//\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX//=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX/=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX::\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX=>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX>>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX?=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH^\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX|=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX||=\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX~=\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\196\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalarm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abinmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcaller\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchomp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchroot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bclosedir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcrypt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdbmclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adbmopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bendgrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nendhostent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tendnetent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vendprotoent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bendpwent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nendservent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcntl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfileno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bformline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgetc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetgrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetgrgid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetgrnam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgethostbyaddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgethostbyname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngethostent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetlogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgetnetbyaddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgetnetbyname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgetnetent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetpeername\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetpgrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetppid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetpriority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOgetprotobyname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEgetprotobynumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetprotoent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetpwent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetpwnam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgetpwuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetservbyname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetservbyport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngetservent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetsockname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngetsockopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTglob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgmtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQioctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alcfirst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlisten\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlocaltime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgrcv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgsnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aopendir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpipe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprototype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tquotemeta\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areaddir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrecv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTredo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trewinddir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscalar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aseekdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsemctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsemget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsemop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsetgrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsethostent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetnetent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetpgrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetpriority\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetprotoent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsetpwent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetservent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsetsockopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshmctl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshmget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashmread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshmwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bshutdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsocket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsocketpair\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsplice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asprintf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstudy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsubstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asymlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asyscall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asysseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsyswrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atelldir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtimes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXuc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aucfirst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQumask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQundef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQutime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awaitpid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\twantarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwarn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbytes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bconstant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdiagnostics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aenglish\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfiletest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asigtrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsubs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTutf8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwarnings\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\=\\w+(\\s|$)\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpod\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL%\\b\\-?0[xX]([0-9a-fA-F]|_[0-9a-fA-F])+\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1slash_safe_escape\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\b\\-?0[bB]([01]|_[01])+\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1slash_safe_escape\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\\b\\-?0[1-7]([0-7]|_[0-7])*\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1slash_safe_escape\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULX\\b\\-?[0-9]([0-9]|_[0-9])*\\.[0-9]([0-9]|_[0-9])*([eE]\\-?[1-9]([0-9]|_[0-9])*(\\.[0-9]*)?)?\SOH\EOT\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1slash_safe_escape\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\b\\-?[1-9]([0-9]|_[0-9])*\\b\SOH\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1slash_safe_escape\b\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1slash_safe_escape\SOH&'\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tip_string\NUL'\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL`\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBackticked\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL.(?:[$@]\\S|%([\\w\\{\\+\\-!]|\\^H)|\\*[^\\d\\*{\\$@%=(])\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_variable\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f<[A-Z0-9_]+>\SOH\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\s*<<(?=\\w+|\\s*[\"'])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2find_here_document\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\s*\\}\\s*/{1,2}\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\s*[)\\]]\\s*/{1,2}\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\w+::\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsub_name_def\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\w+[=]\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\bq(?=[qwx]?\\s*[^\\w\\s])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfind_quoted\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\\bs(?=\\s*[^\\w\\s\\]})])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfind_subst\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\b(?:tr|y)\\s*(?=[^\\w\\s\\]})])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtr\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\b(?:m|qr)(?=\\s*[^\\w\\s\\]})])\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_pattern\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS[\\w_]+\\s*//?\\=?|[<>\"':]//?\\=?\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX//=\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH//\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_slash\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL -[rwxoRWXOeszfdlpSbctugkTBMAC]\\b\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpat_char_class\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpat_char_class\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL^\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\\\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\]\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\[:\\^?[a-z]+:\\]\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apat_ext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apat_ext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ!:<=>\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\#[^)]*\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL)\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\$(?=%1)\SOH\ACK\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f%1[cgimosx]*\SOH\DLE\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_brace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_brace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\}[cgimosx]*\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBpattern_brace_recursive\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBpattern_brace_recursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBpattern_brace_recursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_brace\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpattern_bracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpattern_bracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\][cgimosx]*\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_paren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_paren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\)[cgimosx]*\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL(\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL pattern_paren_internal_recursive\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL pattern_paren_internal_recursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL pattern_paren_internal_recursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_paren\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_slash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpattern_slash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\$(?=/)\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v/[cgimosx]*\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npattern_sq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npattern_sq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v'[cgimosx]*\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNregex_pattern_internal\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL5\\=(?:head[1-6]|over|back|item|for|begin|end|pod)\\s*.*\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT=cut\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPod\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nquote_word\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nquote_word\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\%1\RS\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\DLE\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2quote_word_angular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2quote_word_angular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\>\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL>\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEquote_word_brace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEquote_word_brace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2quote_word_bracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2quote_word_bracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEquote_word_paren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEquote_word_paren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNregex_pattern_internal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNregex_pattern_internal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSregex_pattern_internal_rules_1\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSregex_pattern_internal_rules_2\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSregex_pattern_internal_rules_1\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1[$@][^]\\s{}()|>']\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4find_variable_unsafe\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSregex_pattern_internal_rules_2\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSregex_pattern_internal_rules_1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSregex_pattern_internal_rules_1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\145\\\\c[^\\s\\\\]|\\\\g(\\{(\\w+|\\-\\d+)\\}|\\d+)|\\\\k(\\{\\w+\\}|<\\w+>|'\\w+')|\\\\N\\{[^\\{\\}]*\\}|\\\\o\\{[0-7]+\\}|\\\\[pP](\\{\\w+\\}|P)|\\\\x([0-9a-fA-F]{2}|\\{[0-9a-fA-F]+\\})\SOH\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\\\[anDdSsWw]\SOH\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\[ABbEGLlNUuQdQZz]\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\\\[\\d]+\SOH\ESC\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSregex_pattern_internal_rules_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSregex_pattern_internal_rules_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SOH(?\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apat_ext\NUL[\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpat_char_class\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a()*+?^|\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\{[\\d, ]+\\}\SOH\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\s{3,}#.*$\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1slash_safe_escape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1slash_safe_escape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\s*\\}\\s*/{1,2}\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\s*[)\\]]?\\s*/{1,2}\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__DATA__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__END__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__FILE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__LINE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__PACKAGE__\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQelsif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgiven\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DC1\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\'\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\\\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DC1\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\)\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\\\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX()\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DC1\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\}\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\\\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX{}\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DC1\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\]\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\\\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DC1\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\<\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\\\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\>\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX<>\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL>\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DC1\n\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\\\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\%1\ACK\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\DLE\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2sub_arg_definition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2sub_arg_definition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$%*@\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ&;[\\]\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1slash_safe_escape\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsub_name_def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsub_name_def\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\w+\SOH\DC1\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\$\\S\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_variable\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\s*\\(\SOH\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2sub_arg_definition\SOH::\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKsubst_bracket_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKsubst_bracket_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_maybe_comment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKsubst_bracket_replace\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKsubst_bracket_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKsubst_bracket_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\][cegimosx]*\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBsubst_curlybrace_middle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBsubst_curlybrace_middle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsubst_curlybrace_replace\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsubst_curlybrace_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsubst_curlybrace_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\s+#.*$\SOH\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBsubst_curlybrace_middle\NUL{\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"subst_curlybrace_pattern_recursive\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"subst_curlybrace_pattern_recursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"subst_curlybrace_pattern_recursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsubst_curlybrace_pattern\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsubst_curlybrace_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANsubst_curlybrace_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"subst_curlybrace_replace_recursive\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\}[cegimosx]*\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"subst_curlybrace_replace_recursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"subst_curlybrace_replace_recursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL{\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"subst_curlybrace_replace_recursive\NUL}\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_maybe_comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_maybe_comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL#\f\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_paren_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_paren_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_maybe_comment\NUL)\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_paren_replace\NUL(\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL&subst_paren_pattern_internal_recursive\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&subst_paren_pattern_internal_recursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL&subst_paren_pattern_internal_recursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\ACK\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_paren_pattern\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_paren_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_paren_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\)[cegimosx]*\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_slash_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_slash_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\$(?=%1)\SOH\ACK\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT(%1)\SOH\DLE\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_slash_replace\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMregex_pattern_internal_ip\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_slash_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_slash_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r%1[cegimosx]*\SOH\DLE\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ipstring_internal\b\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsubst_sq_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsubst_sq_pattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3subst_maybe_comment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNregex_pattern_internal\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsubst_sq_replace\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsubst_sq_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsubst_sq_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f'[cegimosx]*\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULg\\([^)]*\\)\\s*\\(?:[^)]*\\)|\\{[^}]*\\}\\s*\\{[^}]*\\}|\\[[^]]*\\]\\s*\\[[^\\]]*\\]|([^a-zA-Z0-9_\\s[\\]{}()]).*?\\1.*?\\1\SOH\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvar_detect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nvar_detect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvar_detect_rules\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1slash_safe_escape\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvar_detect_rules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvar_detect_rules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[\\w_]+\SOH\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH::\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\DLE\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH->\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH++\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH--\RS\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1var_detect_unsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1var_detect_unsafe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvar_detect_rules\SOH\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSAnders Lund (anders@alweb.dk)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX19\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLGPLv2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.pl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.PL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.pm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnormal"
